@@ -43,6 +43,8 @@ typedef enum pu_config_option_t {
   PU_CONFIG_OPTION_DISABLEDOWNLOADTIMEOUT,
   PU_CONFIG_OPTION_PARALLELDOWNLOADS,
 
+  PU_CONFIG_OPTION_PRETTYPROGRESSBAR,
+
   PU_CONFIG_OPTION_SIGLEVEL,
   PU_CONFIG_OPTION_LOCAL_SIGLEVEL,
   PU_CONFIG_OPTION_REMOTE_SIGLEVEL,
@@ -62,9 +64,8 @@ typedef enum pu_config_option_t {
   PU_CONFIG_OPTION_USAGE,
 
   PU_CONFIG_OPTION_DOWNLOADUSER,
-  PU_CONFIG_OPTION_DISABLESANDBOX,
-  PU_CONFIG_OPTION_DISABLESANDBOX_FILESYSTEM,
-  PU_CONFIG_OPTION_DISABLESANDBOX_SYSCALLS,
+  PU_CONFIG_OPTION_DISABLESANDBOXFILESYSTEM,
+  PU_CONFIG_OPTION_DISABLESANDBOXSYSCALLS,
 
   PU_CONFIG_OPTION_INCLUDE
 } pu_config_option_t;
@@ -98,9 +99,10 @@ typedef struct pu_config_t {
   pu_config_bool_t usesyslog;
   pu_config_bool_t verbosepkglists;
   pu_config_bool_t disabledownloadtimeout;
-  pu_config_bool_t disablesandbox;
-  pu_config_bool_t disablesandbox_filesystem;
-  pu_config_bool_t disablesandbox_syscalls;
+  pu_config_bool_t disablesandboxfilesystem;
+  pu_config_bool_t disablesandboxsyscalls;
+
+  pu_config_bool_t prettyprogressbar;
 
   int siglevel;
   int localfilesiglevel;
